from secrets import token_hex
from io import BytesIO
import qrcode

class MeetClient:
    def __init__(self) -> None:
        self.base_url = "https://brie.fi/ng"

    def create_meet(self) -> str:
        unique_id = token_hex(4)
        return f"{self.base_url}/{unique_id[:3:]}-{unique_id[3:6]}-{unique_id[6:]}"

    def create_qr_code(self) -> bytes:
        meet_link = self.create_meet()
        qr = qrcode.QRCode(version=1, box_size=10, border=4)
        qr.add_data(meet_link)
        qr.make(fit=True)
        img = qr.make_image(fill_color="black", back_color="white")
        with BytesIO() as buffer:
            img.save(buffer, format="png")
            return buffer.getvalue()


from setuptools import setup, find_packages

setup(
    name='blitzmeets',
    version='0.1.1',
    description='A utility to create virtual meetings programatically',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Your Name',
    author_email='youremail@example.com',
    url='https://github.com/BliyzJB/BlitzMeets',
    packages=find_packages(),
    install_requires=[
        'requests',
        'qrcode'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
